@@ -1,7 +1,8 @@
 from TTBenchmark import benchmark
+from TTBenchmark import check_benchmark
 from TTBenchmark import check_environment
 from TTBenchmark import constant
-
 from TTBenchmark.benchmark import *
+from TTBenchmark.check_benchmark import *
 from TTBenchmark.check_environment import *
 from TTBenchmark.gen_benchmark import *
