@@ -31,3 +31,13 @@ def check_env_info():
     env["cpu"] = platform.processor()
 
     return env
+
+
+def in_notebook():
+    try:
+        from IPython import get_ipython
+        if 'IPKernelApp' not in get_ipython().config:  # pragma: no cover
+            return False
+    except ImportError:
+        return False
+    return True
